**********************************************************************
**                                                                  **
**     The Polish-French common program for the TDCR LSC-method     **
**              of pure-beta emitters standardization               **
**                                                                  **
**                      >>>    TDCRB-02   <<<                       **
**                                                                  **
**     R. Broda       - OBRI POLATOM, Swierk, Poland                **
**     P. Cassette    - LPRI, DAMRI, CEN, Saclay, France            **
**     K. Maletka     - OBRI POLATOM, Swierk, Poland                **
**     K. Pochwalski  - retired from OBRI POLATOM, Swierk, Poland   **
**                                                                  **
**              Version 02;  Swierk, Saclay;  May 2001              **
**  modification of TDCRB-1 Version 1;  Swierk, Saclay;  April 1999 **
**                                                                  **
**********************************************************************
*
*  Assumption:    PMT are not identical A >< B >< C
*
*                    -----------------------------
*  Maximal values :  I   30 counting points      I
*                    I   15 repetitions          I
*                    I   12 sources              I
*                    -----------------------------
*  SUBROUTINES:
*    DATAEXP  - for selecting an input data set file
*    PARAM-2  - for selecting a radionuclide and a scintillator from
*               the DONNE.TAB file
*    SPECTB   - for calculating beta spectrum
*    INTRP    - for finding by interpolation the best value of kB factor
*    FJON-2   - for calculating scintillation energy spectrum
*    FIT-3    - for calculating counting channels counting efficiencies
*    SOURCE-3 - for calculating source activity and uncertainty
*    DESSIN-5 - for plotting diagrams of counting points vs TDCR values
*               and for printing source activity tables
*    SETSOUR  - for calculating a mean activity of a solution
*    RESULT-5 - for printing and analysing measurement results
*    EFFIC2   - for calculating counting probabilities 
*               (distribution Poisson)
*
*  Notice:
*    1) Results are printed or recorded in the CALC.RES file
*    2) In this source-program subroutine input parameters are
*       written in small letters, while the output parameters - in
*       capital letters
*    3) There are two modes of the TDCRB-02 operation, depending on the
*       IEFF value:
*       - calculation of a solution activity based on the
*         input data set file (IEFF=1)
*       - calculation of a theoretical counting efficiency for a
*         given set of thirty TDCR parameter values (IEFF=2)
*
*************************************************************************
*
	INTEGER NR(12)
	REAL COUNT(5,30,12),ERRC(5,30,12),MASS(12),NA,NM,
     1	   PHEL(30),SCOUNT(5,30),T(12)
	DOUBLE PRECISION A(30),ACT(8,12),AQ(8,12),AX,BQ(8,12),BX,CEAB,
     1	   CEAC,CEBC,CED,CET,DIFF(30),DEL,EB(500),EFFAB(30),
     2	   EFFAC(30),EFFBC(30),EFFD(30),EFFT(30),ER1,ERR(30),ERRK(30),
     3	   ETA1,ETA2,ETA3,ETAI,ETA1M(30),ETA2M(30),ETA3M(30),
     6	   ETAX,FE(500),KB(8),MKB,N0SOL1,SACT(12),SIGAX(8,12),SIGAXK,
     4	   SIGMA(8,12),SIGMAK(12),SKB(12),SLOPE(8),SLOPEX,SPEB(500),
     5	   SSIGMA(12),TDCR(30),TDCRI,TDCR1,TDCR2,TDCR3,TDCRM(12),XKB
	CHARACTER REP*1
*
************************************************************************
*
        WRITE (*,'(/'' >>>>   PROGRAM TDCRB-02   <<<<'')')
* 
*  options:  printing results or saving them in the CALC.RES file
*
10	WRITE (*,'(/1X,''==>  Print the results of calculation   (1)''/
     1	   6X,''or save them in a file CALC.RES ?  (2) '',\)')
	READ (*,*) I
	IF (I.EQ.1) THEN
	   NOUT1 = 7
	   OPEN (NOUT1,FILE='PRN')
	   NOUT = NOUT1
	ELSE IF (I.EQ.2) THEN
	   NOUT2 = 8
	   OPEN (NOUT2,FILE='CALC.RES')
	   NOUT = NOUT2
	ELSE
	   GO TO 10
	ENDIF
        WRITE (NOUT,'('' >>>>   PROGRAM TDCRB-02   <<<<'')')
*
*  adopted set of thirty TDCR values for calculation of the theoretical
*  counting efficiency, when IEFF=2
*
15	WRITE (*,'(/1X,''==>  Calculation of the solution radioactive'',
     1	   '' concentration  (1)''/6X,''or the theoretical counting '',
     2	   ''efficiency only?'',11X,''(2) '',\)')
	READ (*,*) IEFF
	IF (IEFF.NE.1.AND.IEFF.NE.2) GO TO 15
	IF (IEFF.EQ.2) GO TO 50
*
*************************************************************************
*   SUBROUTINE DATEXP
*   - For selecting the input data set file with a set of sources as well
*     as background counts, masses of sources and counting time. Values
*     of number of counting points, repetition and number of sources are
*     contained in the file. Information concerning the measurement is
*     to be input and is printed.
*     Means of counts are taken, counting points are calculated,
*     background is subtracted and uncertainties are calculated.
*
*   Parameters and tables:
*     nout- ordinal number of the output device
*     NS - number of sources
*     MASS(ns) - table of sources masses
*     T(ns) - table of counting time applied to different sources
*     NP - applied number of counting points
*     NR(ns) - table of repetition applied to different sources
*     COUNT(i1,i2,i3) - table of counting points
*     ERRC(i1,i2,i3) - table of counting point uncertainties
*                      (standard deviation)
*                      i1 - ordinal number of a counting channel
*                           1-AB, 2-BC, 3-AC, 4-T, 5-D
*                      i2 - ordinal number of a counting point
*                      i3 - ordinal number of a source
*
	CALL DATAEXP (nout,NS,MASS,T,NP,NR,COUNT,ERRC)
*
************************************************************************
*   SUBROUTINE PARAM     ( Version  PARAM-2)
*   - For selecting and printing a radionuclide and a scintillator data,
*     registered in the DONNE.TAB file. The data are used to calculate 
*     the electron and scintillation beta spectra.
*
*  Parameters:
*     IPRINT - printing options:
*      =1  printing tables and plotting diagrams for all kB values
*      =2  plotting diagrams but not tables for all kB values
*      =3  printing table and plotting a diagram for interpolated
*          kB value only
*     NA - atomic number
*     NM - mass number
*     ISIGNE - character of beta decay
*     EMAX - maximal energy of the beta spectrum
*     IFORBN - forbiddenes of the beta decay
*     R - radius of the scintillator cylinder
*     H - height of the scintillator cylinder
*     RO - density of the scintillator
*     ZA - ratio of the atomic to the mass number of the scintillator
*     EJ - mean exciting energy of the scintillator molecules
*     DEL - acceptable difference between calculated and 
*           experimental TDCR values
*     NCAN - number of intervals in the beta spectrum
*     KB - ionisation quenching parameter kB
*     NKB - adopted number of kB parameter values (only NKB-1 different
*           kB parameter values are chosen for interpolation)
*
50	CALL PARAM (nout,ieff,IPRINT,NA,NM,ISIGNE,EMAX,IFORBN,R,H,RO,
     1	            ZA,EJ,DEL,NCAN,KB,NKB)
*
***********************************************************************
*   SUBROUTINE SPECTB
*   - For calculating the beta-spectrum for a given radionuclide.
*     Spectrum is divided into NCAN intervals.
*
*   Tables:
*     SPEB(ncan) - beta spectrum
*     EB(ncan)   - beta energies of the spectrum (energies are taken
*                  from the middle of each interval)
*
	CALL SPECTB (na,nm,isigne,emax,iforbn,ncan,EB,SPEB)
*
*   calculation of succeeding sources of a set;
*   TDCR(ip) - experimental TDCR parameter at different counting points
*   ERR(ip)  - uncertainty of a counting point (ip)
*              (taken as uncertainty ERRC of sum of double
*              coincidence, e.g. standard deviation)
*
80	IF (IEFF.EQ.2) THEN
	   IX = 22
	   ETAI = 102.1D0*EXP(((1.335-ALOG10(EMAX))/0.925)*ALOG(10.))
	   WRITE (NOUT,'(/1X,''THEORETICAL COUNTING EFFICIENCY FOR '',
     1	      ''A GIVEN kB AND ETA0 PARAMETER VALUES''//8X,''kB     '',
     3	      ''ETA0     TDCR     PHEL    effAB     effT     effD''/)')
	   GO TO 180
	ENDIF
*
	IS = 0
	MKB = 0.D0
*
100	IS = IS+1
	   WRITE (NOUT,'(/'' SOURCE No.'',I2,4X,''MASS='',F9.4,
     1	      '' mg'',3X,''COUNTING TIME='',F5.0,'' s'',3X,
     2	      ''REPETITIONS='',I2)') IS,MASS(IS),T(IS),NR(IS)
*
*     calculation of the experimental TDCR parameter value at each
*     counting point for all sources
*
	   TDCRM(IS) = 0.D0
	   DO 150 IP=1,NP
	      TDCR(IP) = COUNT(4,IP,IS)/COUNT(5,IP,IS)
	      IF (TDCR(IP).GT.TDCRM(IS)) TDCRM(IS)=TDCR(IP)
	      ERR(IP) = ERRC(5,IP,IS)
	      DO 150 NC=1,5
	         SCOUNT(NC,IP) = COUNT(NC,IP,IS)
150	      CONTINUE
*
***********************************************************************
*   SUBROUTINE INTRP
*   - For finding by interpolation the kB ionization quenching
*     parameter value (KB(NKB)), at which a slope of the regression line
*     of the set of counting points is equal to zero (SLOPEX=0).
*
	   JJ = -1
180	   NKB2 = NKB+2
	   DO 200 K=1,NKB2
	      IF (K.EQ.NKB) THEN
	         IF (IEFF.EQ.2) GO TO 200
		 IK = NKB-1
	         SLOPEX = 0.D0
*
                 CALL INTRP (nout,ik,slope,kb,slopex,KB(NKB))
*
                 IF (KB(K).LT.0.D0) KB(K)=0.D0
*
	      ELSE IF (K.GT.NKB) THEN
	         IF (IEFF.EQ.2) GO TO 200
	         JJ = -JJ
	         SLOPEX = JJ*SIGAX(NKB,IS)
*
                 CALL INTRP (nout,ik,slope,kb,slopex,KB(K))
*
                 IF (KB(K).LT.0.D0) KB(K)=0.D0
	      ENDIF
	      XKB = KB(K)
*
**********************************************************************
*  SUBROUTINE FJON
*  - For calculating scintillation energies of all intervals of the
*    beta-spectrum (taking into account a given kB parameter value)
*
*  Tables:
*    FE(ncan) -  scintillation energy
*
	      CALL FJON (ncan,eb,xkb,r,h,ro,za,ej,FE)
*
**********************************************************************
*  SUBROUTINE FIT     ( Version  FIT-2 )
*  - For calculating all counting point counting efficiencies (at each
*    counting channel) taking into account the scintillation spectrum.
*    In each counting point the calculated theoretical TDCR parameter
*    is fitted to the experimental one.
*
*  Parameters and tables:
*    CEAB -  counting efficiency at the double coincidence channel AB
*    CEBC -     "         "       "  "     "           "       "   BC
*    CEAC -     "         "       "  "     "           "       "   AC
*    CET  -     "         "       "  "  triple         "       "   T
*    CED  -     "         "       "  "  sum of double  "       "   D
*    ETA1M(np) - figure of merit of PM-tube A at each counting point
*    ETA2M(np) -  "     "    "   "  PM-tube B     "      "       "  
*    ETA3M(np) -  "     "    "   "  PM-tube C     "      "       "  
*    PHEL(np) - table of expected number of photoelectrons in the
*               detector at each counting point
*
*  Assumptions: The Poissonian photoelectron statistics is applied.
*
	IF (IEFF.EQ.2) THEN
	   X2 = 1.5
	   IF (IX.EQ.1) X2=1.
	   X1 = 1.333
	   X0 = X1
	   ETAX = ETAI
	   DO 18 I=1,IX
	      IF (X0.EQ.X2) THEN
	         X0 = X1
	      ELSE
	         X0 = X2
	      ENDIF
	      ETAX = ETAX/X0
	      ETA1 = ETAX/3.
	      ETA2 = ETAX/3.
	      ETA3 = ETAX/3.
*
	      CALL EFFIC2 (eta1,eta2,eta3,ncan,fe,speb,CEAB,CEBC,CEAC,
     1	                   CET,CED,PHELI)
*
	      TDCRI = CET/CED
	      WRITE(NOUT,'(2X,F8.4,1X,F8.3,1X,F8.4,1X,F8.2,3F9.4))')
     1	         XKB,ETAX,TDCRI,PHELI,CEAB,CET,CED
	      WRITE (*,'(2X,F8.4,1X,F8.3,1X,F8.4,1X,F8.2,3F9.4))')
     1	         XKB,ETAX,TDCRI,PHELI,CEAB,CET,CED
18	      CONTINUE
	   IF (IX.NE.1) WRITE (NOUT,*)
	   GO TO 200
	ENDIF
*
	      DO 300 IP=1,NP
	         TDCRI = TDCR(IP)
	         TDCR1 = SCOUNT(4,IP)/SCOUNT(1,IP)
	         TDCR2 = SCOUNT(4,IP)/SCOUNT(2,IP)
	         TDCR3 = SCOUNT(4,IP)/SCOUNT(3,IP)
*
	         CALL FIT (ncan,fe,speb,tdcr1,tdcr2,tdcr3,del,
     1	                   CEAB,CEBC,CEAC,CET,CED,PHEL(IP),ETA1M(IP),
     2	                   ETA2M(IP),ETA3M(IP))
*
*   Mutual relation of the counting channels, AB+BC+AC=2T+D, is
*   tested by checking, if DIFF=(AB+BC+AC)/(2T+D)-1 is equal to 0;
*   A(ip), source activity at a counting point, is calculated by using
*   counting rate at the sum of double coincidence channel.
*
*
	         A(IP) = SCOUNT(5,IP)/CED
	         ERRK(IP) = ERR(IP)/CED
	         DIFF(IP) = (SCOUNT(1,IP)+SCOUNT(2,IP)+
     1	                    SCOUNT(3,IP))/(2.0*SCOUNT(4,IP)+
     2	                    SCOUNT(5,IP))-1.0
	         EFFAB(IP) = CEAB
	         EFFBC(IP) = CEBC
	         EFFAC(IP) = CEAC
	         EFFT(IP) = CET
	         EFFD(IP) = CED
300	         CONTINUE
*
************************************************************************
*   SUBPROGRAM SOURCE      (Version  SOURCE-3 )
*   - For calculating the source activity as a mean of activities taken
*     at all counting points. For this purpose a regression line of the
*     set of counting points is plotted.
*
*   Parameters and tables:
*     ACT(nkb,ns) - table of source activities for adopted kB parameters
*     SIGMA(nkb,ns) - standard deviation of source activities for
*                     adopted kB parameters
*     AX,BX - parameters of the regression line A=TDCR*AX+BX of the set
*             of counting points
*     SIGAX(nkb,ns) - standard deviation of AX parameters for adopted
*                     kB parameters
*
              CALL SOURCE (np,a,tdcr,ACT(K,IS),SIGMA(K,IS),AX,BX,
     1                     SIGAXK)
*
*   SLOPE - slope of the regression line of the set of counting points
*
              SLOPE(K) = (AX/ACT(K,IS))*100.
	      SIGAX(K,IS) = DSQRT(SIGAXK**2+(AX*SIGMA(K,IS)/
     1	                          ACT(K,IS))**2)*100./ACT(K,IS)
	      AQ(K,IS) = AX
	      BQ(K,IS) = BX
*
************************************************************************
*   SUBROUTINE DESSIN     ( Version DESSIN-5 )
*    - For plotting diagrams of counting points vs TDCR parameter values
*      and for printing calculated source activity tables.
*
	      NOPRINT = 1
	      IF (IPRINT.EQ.3.AND.K.LT.NKB) NOPRINT=0
*
	      CALL DESSIN (nout,iprint,noprint,is,np,a,errk,tdcr,eta1m,
     1	                   eta2m,eta3m,scount,diff,effab,effbc,effac,
     2	                   efft,effd,phel,xkb,act(k,is),sigma(k,is))
*
200	      CONTINUE
*
	   IF (IEFF.EQ.2) THEN
	      WRITE (*,'(/1X,''       kB     ETA0     TDCR     PHEL'',
     1	         ''    effAB     effT     effD''/4X,''[cm/MeV]'',
     2	         ''  [el/keV]'',13X,''\__expected number of photoelec'',
     3	         ''trons in total'')')
              WRITE (*,'(/1X,''==>  Calculation for another ETA0 '',
     1	         ''value ? (Y/N) '',\)')
	      READ (*,'(A)') REP
	      IF (REP.EQ.'N'.OR.REP.EQ.'n') THEN
	         STOP
	      ELSE
	         IX = 1
400	         WRITE (*,'(1X,''==>  Give a new value of ETA0 = '',\)')
	         READ (*,*) ETAI
	         WRITE (*,*)
	         WRITE (NOUT,'(/4X,''THEORETICAL COUNTING EFFICIENCY '',
     1	            ''FOR A GIVEN kB AND ETA0 PARAMETER VALUES''//8X,
     2	            ''kB     ETA0     TDCR     PHEL    effAB     effT'',
     3	            ''     effD''/)')
	         GO TO 180
	      ENDIF
	   ENDIF
*
	   SKB(IS) = KB(NKB)
	   MKB = MKB+SKB(IS)
	   SACT(IS) = ACT(NKB,IS)
	   SSIGMA(IS) = DSQRT(SIGMA(NKB,IS)**2+
     1	                ((ACT(NKB+2,IS)-ACT(NKB+1,IS))/2.)**2)
	   SIGMAK(IS) = DABS(KB(NKB+2)-KB(NKB+1))/2.
	   IF (IS.LT.NS) GO TO 100
	CLOSE (2)
*
***********************************************************************
*   SUBROUTINE SETSOUR
*   - For calculating the activity of a set of sources, 
*     e.g. the solution activity.
*
*   Parameters:
*     N0SOL1 - mean activity of the solution
*     ER1 - mean activity standard deviation
*
        CALL SETSOUR (ns,sact,ssigma,N0SOL1,ER1)
*
***********************************************************************
*   SUBROUTINE RESULT       (Version  RESULT-5 )
*   - For printing measurement results
*
        CALL RESULT (nout,ns,nkb2,mass,skb,aq,sigax,kb,sigmak,act,
     1		     sigma,ssigma,n0sol1,er1,tdcrm) 
*
	WRITE (*,'(/1X,''==>  Calculation of the theoretical '',
     1	   ''counting efficiency table''/6X,''for the mean value '',
     2	   ''of the interpolated kB parameter ? (Y/N) '',\)')
	READ (*,'(A)') REP
	IF (REP.NE.'N'.AND.REP.NE.'n') THEN
	   IEFF = 2
	   KB(1) = MKB/NS
	   NKB = 2
	   GO TO 80
	ENDIF
*
	STOP
	END
************************************************************************
*   SUBROUTINE DATAEXP
*   - For selecting the input data set file with a set of sources,
*     masses of sources and counting time, as well as the input data
*     set file with a background counts.
*     Values of number of counting points, repetition and number of
*     sources are then contained in the file. Information concerning the
*     measurement is to be input and is printed.
*     Means of counts are taken, counting points are calculated, 
*     background is subtracted and uncertainties calculated
*
*     The input data set file with a background counts could be omitted
*     during calculation. The calculation could be performed even if
*     only one repetition in each counting point is noted.
*
*  Parameters and tables:
*     NOUT - ordinal number of printing device
*     NS - number of sources (maximal = 12)
*     MASS(ns) - table of source masses
*     T(ns) - table of counting times applied for different sources
*     NP - applied number of separate counting points (maximal = 30)
*     NR(ns) - table of repetitions applied for different sources
*              (maximal = 15)
*     COUNT(i1,i2,i3) - table of counting points
*     ERRC(i1,i2,i3) - table of counting point uncertainties
*                      i1 - ordinal number of a counting channel
*                           1-AB, 2-BC, 3-AC, 4-T, 5-D 
*                      i2 - ordinal number of a counting point
*                      i3 - ordinal number of a source
*
	SUBROUTINE DATAEXP (nout,NS,MASS,T,NP,NR,COUNT,ERRC)
*
	REAL MASS(NS),T(NS),ERRC(5,30,NS),COUNT(5,30,NS),UFOC(30)
        DOUBLE PRECISION SX(5,15),X(5,15),XMP(5,15),SXMP(5,30)
	INTEGER NR(NS)
        CHARACTER INFS*80,NOMFIC*14,NUCL*9,DATE*12,NAME*14,REP*1,REP0*1
*
        WRITE (*,'(/'' ==>  Do you want to read the '',
     1     ''file with a background counts ? (Y/N) '',\)')
        READ (*,'(A1)') REP0
        IF (REP0.EQ.'N'.OR.REP0.EQ.'n') GO TO 50
*
*  reading the input data set file with a background counts
*
20	WRITE (*,'(/'' ==>  Name of the input data set file with a '',
     1	   ''background counts: '',\)')
	READ (*,'(A)') NAME
	OPEN (2,FILE=NAME,STATUS='OLD',ERR=30)
	GO TO 40
30	WRITE (*,'('' ***  SUCH A FILE DO NOT EXISTS  !!!'')')
        WRITE(*,'(/'' ==>  Do you want to STOP the program ? (Y/N)'')')
        READ(*,'(A1)')REP
        IF(REP.EQ.'Y'.OR.REP.EQ.'y') THEN
	   GO TO 920
	ELSE
	   GO TO 20
        ENDIF
40	READ (2,'(A)') NOMFIC
  	READ (2,'(A9,A12)') NUCL,DATE
	READ (2,'(A80)') INFS
	WRITE (NOUT,'(/'' ** '',A12,2X,''('',A12,'') '',A80)')
     1	   DATE,NOMFIC,INFS
	WRITE (*,'(4X,''BACKGROUND: '',A80)') INFS
	READ (2,*) NS,NP
	READ (2,*) (MASS(I),I=1,NS)
	READ (2,*) (UFOC(I),I=1,NP)
*
*  The table SXMP(j,l) contains mean values of the background for each (l)
*  counting point and each (i) counting channel 1-AB, 2-BC, 3-CA, 4-T, 5-D.
*
*  calculation of the mean background values 
*
	READ (2,*) TMP,NREPS
	DO 305 L=1,NP
	   DO 305 I=1,NREPS
	      READ (2,*) (XMP(LT,I),LT=1,5)
	      DO 305 J=1,5
305              SXMP(J,L) = SXMP(J,L)+XMP(J,I)/(NREPS*TMP)
	CLOSE (2)
*
*  reading the input data set file with a set of sources counts
*
50      WRITE (*,'(/'' ==>  Name of the input data set file with a '',
     1	   ''set of sources counts: '',\)')
	READ (*,'(A)') NAME
	OPEN (2,FILE=NAME,STATUS='OLD',ERR=60)
	GO TO 70
60	WRITE (*,'('' ***  SUCH A FILE DO NOT EXISTS  !!!'')')
        WRITE(*,'(/'' ==>  Do you want to STOP the program ? (Y/N)'')')
        READ(*,'(A1)')REP
        IF(REP.EQ.'Y'.OR.REP.EQ.'y') THEN
	   GO TO 920
	ELSE
	   GO TO 50
        ENDIF
70	READ (2,'(A)') NOMFIC
  	READ (2,'(A9,A12)') NUCL,DATE
	READ (2,'(A80)') INFS
	WRITE (NOUT,'(/'' ** '',A12,2X''('',A12,'') '',A80)')
     1	   DATE,NOMFIC,INFS
	WRITE (*,'(4X,''SOURCE: '',A80)') INFS
	READ (2,*) NS,NP
	READ (2,*) (MASS(I),I=1,NS)
	READ (2,*) (UFOC(I),I=1,NP)
*
*  T(is) - table of counting times for different sources
*  NR(is) - table of repetitions for different sources
*
	DO 400 IS=1,NS
	   READ (2,*) T(IS),NR(IS)
*
*  reading all (i) repetitions of all counting points X(j,i),
*  subtracting background and calculating mean values of counts
*  per second per gram SX(j,l) for all (j) counting channels
*  1-AB, 2-BC, 3-CA, 4-T, 5-D, all (l) counting points and 
*  all (is) sources
*
	DO 300 L=1,NP
	   DO 309 J=1,5
              IF (REP0.EQ.'N'.OR.REP0.EQ.'n') SXMP(J,L)=0.
309	      SX(J,L) = 0.
*
	   DO 310 I=1,NR(IS)
	      READ (2,*) (X(LT,I),LT=1,5)
	      DO 310 J=1,5
                 X(J,I) = (X(J,I)/T(IS)-SXMP(J,L))/MASS(IS)
310	         SX(J,L) = SX(J,L)+X(J,I)/NR(IS)
*
*  mean values of counts per second per gram COUNT(j,l,is) and
*  uncertainties ERRC(j,l,is) for all counting channels (j), 
*  all counting points (l) and all sources (is) are calculated
*
	   DO 313 J=1,5
	      COUNT(J,L,IS)= SX(J,L)
              ERRC(J,L,IS) = 0.
              IF (NR(IS).EQ.1) GO TO 313
	      SXJL = SX(J,L)
	      S = 0.
	      DO 314 I=1,NR(IS)
314	         S = S+(SXJL-X(J,I))**2
              ERRC(J,L,IS) = SQRT(S/(NR(IS)*(NR(IS)-1)))
313           CONTINUE
*
300	   CONTINUE
400	CONTINUE
	CLOSE (2)
*
	RETURN
920	STOP
	END
************************************************************************
*  SUBROUTINE PARAM      ( Version  PARAM-2 )
*  - For selecting and printing the radionuclide and the scintillator
*    data registered in the DONNE.TAB file. The data are used to 
*    calculate the beta spectrum and the scintillation spectrum.
*
*  Input:
*    NOUT - ordinal number of the output device
*    IEFF - mode of the main program operation:
*           calculation of a solution activity (IEFF=1)
*           or calculation of a theoretical counting efficiency (IEFF=2)
*  Output:
*    IPRINT - printing options:
*      =1 or -1  printing tables and diagrams for all kB values
*      =2 or -2      "    diagrams but not tables for all kB values
*      =3 or -3      "    table and diagram only for interpolated kB value
*    NA - the radionuclide atomic number
*    NM - the radionuclide mass number
*    ISIGNE - the character of beta decay
*             =-1 for beta minus;  =+1 for beta plus
*    EMAX - maximal energy of beta spectrum [keV]
*    IFORBN - forbiddenes of the beta transition (b.t.)
*             (an absolute value of change of the nuclear spin)
*             =1  allowed b.t. or 1-st forbidden b.t.
*             =2  1-st forbidden unique b.t. or 2-nd forbidden b.t.
*             =3  2-nd forbidden unique b.t. or 3-rd forbidden b.t.
*             =4  3-rd forbidden unique b.t.
*    R - radius of the scintillator cylindrical column
*    H - height of the scintillator cylindrical column
*    RO - density of the scintillator
*    ZA - ratio of the atomic to the mass number of the scintillator
*    EJ - mean exciting energy of the scintillator molecules
*    DEL - acceptable difference between calculated and 
*          experimental TDCR values
*    NCAN - adopted number of intervals in the beta spectrum
*    KB - ionisation quenching parameter kB
*    NKB - adopted number of different parameters kB values (only NKB-1
*          different kB parameter values are chosen for interpolation)
*
	SUBROUTINE PARAM (nout,ieff,IPRINT,NA,NM,ISIGNE,EMAX,IFORBN,
     1                    R,H,RO,ZA,EJ,DEL,NCAN,KB,NKB)
	DOUBLE PRECISION DEL,KB(6)
        REAL NA,NM
	CHARACTER NUCL*9,DAN*70,REP*1
*
        OPEN (3,FILE='DONNE.TAB',STATUS='OLD',ERR=905)
*
*  reading DONNE.TAB data file:
*    JB - number of different radionuclides in the file
*    NUCL - name of a radinuclide
*    A - mass number of a radionuclide
*    Z - atomic number of a radionuclide
*    INTER - forbiddenes of the beta transition (IFORBN),
*            it's sign correspond to the character of beta decay ISIGNE
*            (beta minus or beta plus)
*    JS - number of different scintillators in the file
*    DAN - name of a scintillator
*    EMA - maximal energy of the beta spectrum [keV]
*    RX - radius of the scintillator cylindrical column
*    HX - height of the scintillator cylindrical column
*    ROX - density of the scintillator
*    ZAX - ratio of the atomic to the mass number of the scintillator
*    EJX - mean exciting energy of the scintillator molecules
*
	IU1=0
21	WRITE(*,'(/1X,''==>  Select the radionuclide for calculation'',
     1	   '' (by "Y")''/)')
22	READ (3,*) JB
	DO 60 I=1,JB
	   READ (3,'(A)') NUCL
	   READ (3,*) A,Z,INTER,EMA
	   IF(IU1.EQ.1) GO TO 60
	   WRITE (*,'(10X,I2,'')'',A10,''  '',\)') I,NUCL
	   READ (*,'(A1)') REP
	   IF (REP.NE.'Y'.AND.REP.NE.'y') GO TO 60
	   IU1=1
	   WRITE (NOUT,'(/1X,14(1H*)/1X,''*'',12X,''*''/1X,''*'',A12,
     1	      ''*''/1X,''*'',12X,''*''/1X,14(1H*)/)') NUCL
	   NM = A
	   NA = Z
	   ISIGNE = ISIGN(1,INTER)
	   EMAX = EMA
	   IFORBN = IABS(INTER)
60	   CONTINUE
*
	IF(IU1.EQ.0) THEN
	   WRITE(*,'(/1X,''==>  Do you want to STOP the program ? '',
     1	      ''(Y/N) '',\)')
	   READ(*,'(A1)') REP
	   IF(REP.EQ.'Y'.OR.REP.EQ.'y') THEN
	      GO TO 908
           ELSE
              REWIND(3)
              GO TO 21
           ENDIF
        ENDIF   
*
*  choice of the scintillator
*
        IU2=0
   	READ (3,*)
	READ (3,*) JS
	WRITE (*,'(/1X,''==>  Select the scintillator (by "Y"):''/)')
   	DO 62 I=1,JS
	   READ (3,'(A)') DAN
	   READ (3,*) RX,HX,ROX,ZAX,EJX
           IF(IU2.EQ.1) GO TO 62
	   WRITE (*,'(1X,I2,'')'',A70,\)') I,DAN
	   READ (*,'(A1)') REP
	   IF (REP.NE.'Y'.AND.REP.NE.'y') GO TO 62
           IU2=1
	   WRITE (NOUT,'('' Scintillator: '',A70)') DAN
	   R = RX
	   H = HX
	   RO = ROX
	   ZA = ZAX
	   EJ = EJX
62	   CONTINUE
*
        IF(IU2.EQ.0) THEN
	   WRITE(*,'(/1X,''==>  Do you want to STOP the program ? (Y/N)'',
     1	      \)')
           READ(*,'(A1)') REP
           IF(REP.EQ.'Y'.OR.REP.EQ.'y') THEN
              GO TO 908
           ELSE
              REWIND(3)
              GO TO 22
           ENDIF
        ENDIF
	CLOSE (3)
*
* choice of calculation parameters:
* DEL - admissible difference between TDCR calculated and experimental values
* NCAN - the adopted number of intervals in beta spectrum (maximum = 500)
*
	DEL = 0.00000001D0
	WRITE (NOUT,'(1X,''DEL = '',F9.8,''  - the admissible '',
     1	   ''difference between calculated and''/20X,
     2	   ''experimental TDCR value'')') DEL
*
	NCAN = 500
	WRITE (NOUT,'(1X,''NCAN = '',I4,6X,''- the number of '',
     1	   ''intervals in beta spectrum'')') NCAN
*
* choice of kB parameter values for interpolation
*
           NKB=6     
	   KB(1) = 0.006D0
	   KB(2) = 0.009D0
	   KB(3) = 0.012D0
	   KB(4) = 0.015D0
	   KB(5) = 0.018D0
*
100	WRITE(*,'(/'' Following values of the kB parameter are chosen'',
     1     '' for interpolation:''/1X,5F8.4,/1X,''==>  Do you accept '',
     2	   ''above values ? (Y/N) '',\)') (KB(II),II=1,5)
	READ (*,'(A1)') REP
        IF(REP.EQ.'N'.OR.REP.EQ.'n') THEN
	   DO 150 K1=1,5
	      WRITE (*,'(''==>  A new value of kB('',I1,'') = '',\)') K1
150	      READ(*,*) KB(K1)
	   GO TO 100
	ENDIF
*
	IF (IEFF.EQ.2) THEN
     	   WRITE (NOUT,'(/'' kB     - ionization quenching kB '',
     1	   ''parameter [cm/MeV]''/'' TDCR   - given (experimental) '',
     2	   ''TDCR parameter''/'' ETA0   - figure of merit [photo'',
     3	   ''electrons/keV]''/'' PHEL   - number of photoelectrons '',
     4	   ''in total in the detector''/'' effAB, effBC, effAC, ef'',
     5	   ''fT, effD - counting efficiencies of counting channels''/)')
	   GO TO 903
	ENDIF
*
	WRITE (*,'(/'' ==>  Select the printing option:''/
     1	 6X,''- tables and diagrams for all kB values            (1) ''/
     2	 6X,''- diagrams but not tables for all kB values        (2) ''/
     3	 6X,''- table and diagram only for interpolated kB value (3) '',
     4	 \)')
	READ (*,*) IPRINT
*
	IF (IPRINT.NE.2)
     %	   WRITE (NOUT,'(/4X,''A      - counting point activity'',
     1	   '' [kBq/g]''/4X,''SIGMA  - counting point activity '',
     2	   ''uncertainty (standard deviation)''/4X,
     3	   ''ETA0   - figure of merit [photoelectrons/keV]''/4X,
     4	   ''PHEL   - number of photoelectrons in the detector''/4X,
     5	   ''DIFF   - test of mutual relation of the counting channels''
     6	   /4X,''TDCR   - experimental TDCR parameter''/4X,''AB, '',
     7	   ''BC, CA, T, D - mean counting rate in a given counting '',
     8	   ''channel''/23X,''per source mass [cps/mg]''/4X,''effAB, '',
     9	   ''effBC, effAC, effT, effD - counting efficiencies of''/38X,
     #	   ''counting channels'')')
*
903	RETURN
905	STOP ' *** The DONNE.TAB file do not exist !!!'
908	STOP
	END
***********************************************************************
*  SUBROUTINE SPECTB
*  - For calculation of beta spectrum of a given radionuclide.
*    Spectrum is divided into NCAN intervals.
*
*  Input:
*    NA - radionuclide atomic number
*    NM - radionuclide mass number
*    ISIGNE - character of beta decay
*             =-1 for beta minus;  =+1 for beta plus
*    EMAX - maximal energy of the beta spectrum [keV]
*    IFORBN - forbiddenes of the beta transition (b.t.)
*             (an absolute value of change of the nuclear spin)
*             =1  allowed b.t. or 1-st forbidden b.t.
*             =2  1-st forbidden unique b.t. or 2-nd forbidden b.t.
*             =3  2-nd forbidden unique b.t. or 3-rd forbidden b.t.
*             =4  3-rd forbidden unique b.t.
*    NCAN - number of intervals of the beta spectrum
*  Output:
*    SPEB(ncan) - beta spectrum
*    EB(ncan) - beta energies of the spectrum (energies are taken
*               in the middle of each interval)
*
      SUBROUTINE SPECTB (na,nm,isigne,emax,iforbn,ncan,EB,SPEB)
      DOUBLE PRECISION UNTIER,PI,ALPHA,GAMMA,EM,R,W,
     1	WMA,DW,SOM,SPI,SPEB(NCAN),EB(NCAN),Z,AM,EMA,DEM    
      REAL NA,NM
*
      AM    = DBLE(NM)
      Z     = DBLE(NA-ISIGNE)
      NSIGNE = -ISIGNE
      EMA  = DBLE(EMAX*0.001)
      UNTIER= 1.D0/(1.D0+2.D0)
      PI    = 3.141592653589793
      ALPHA = 1.D0/137.0359895D00
      GAMMA = ( 1.D0 - (ALPHA*Z)**2 )**0.5
      EM    = 0.51099906D00
*
*  the 1/ALPHA and EM constants are taken from the 1986 work
*  (E.R.COHEN, B.N.TAYLOR, CODATA BULLETIN NO 63, NOV 1986)
*  R - the nuclear radius in units of the Compton wave
*      (GOVE and MARTIN, NUCLEAR DATA TABLES, 10, P210)
*  AM - radionuclide mass number
*
      R     = 0.002908D0*AM**(UNTIER) - 0.002437D0*AM**(-UNTIER)
      W   = EMA / EM
*
*  WMA - maximal relativistic energy in M0C2 units
*  DW - interval of the beta spectrum
*
      WMA = W + 1.D0
      DW  = W / NCAN
*
*  W - energy taken of the middle of the beta spectrum interval
*  Subroutine DNSDW - for calculation of density dN/dW for W energy
*
      DO 1,I=1,NCAN
         W = 1.D0 + DW*(2.D0*DBLE(FLOAT(I))-1.D0)/2.D0
         EB(I)= W
         CALL DNSDW
     %   (z,nsigne,wma,w,SPI,alpha,pi,gamma,r,iforbn)
         SPEB(I)= SPI
1        CONTINUE
*
*  Now begins the spectrum (SPE) normalization by integration
*  in [0,EMA] interval (integral for EN energy in keV )
*
      SOM = 0.D0
      DEM = EMA*1000./NCAN
      DO 4 I=1,NCAN
4        SOM = SOM+SPEB(I)
      DO 2,I=1,NCAN
         EB(I) = DEM*(DBLE(FLOAT(I)-0.5D0))
2	 SPEB(I)=SPEB(I)/SOM
      RETURN
      END
*
*-------------------------------------------------------------------------
*  Subroutine DNSDW calculates the spectrum density for W energy
*
      SUBROUTINE DNSDW
     %   (z,nsigne,wma,w,SPI,alpha,pi,gamma,r,iforbn)
      DOUBLE PRECISION Z,WMA,W,SPI,ALPHA,PI,GAMMA,R,COUL,
     %   DELTA,ETANU,WNU,ETAEL,FERMI
      ETAEL=DSQRT(W**2-1.D0)
*
*  ETAEL - electron moment
*  ETANU - neutrino moment (in reduced units, moment and energy
*          of neutrino are represented by the same number because
*          of it's zero mass)
*  STAT - statistic factor
*
      WNU  = WMA - W
      ETANU= WNU
      STAT = ETAEL * W * ETANU**2
      DELTA= ALPHA * Z * W / ETAEL
*
*  FERMI - Fermi funtion; COUL - Coulomb factor
*
      COUL =  FERMI(NSIGNE,ETAEL,PI,R,GAMMA,DELTA)
*
      GOTO (1,3,5,7) IFORBN
*
*  allowed beta transition or 1-st forbidden beta transition
*
1     FORM = 1
      GOTO 9
*
*  1-st forbidden unique beta transition or 2-nd forbidden beta transition
*
3     FORM = ETAEL**2 + ETANU**2
      GOTO 9
*
*  2-nd forbidden unique beta transition or 3-rd forbidden beta transition
*
5     FORM = ETAEL**4 + ETANU**4 + ETAEL**2*ETANU**2*10/3
      GOTO 9
*
*  3-rd forbidden unique beta transition
*
7     P2   = ETAEL * ETAEL
      Q2   = ETANU * ETANU
      FORM = P2**3 + Q2**3 + 7*P2*Q2*(P2+Q2)
9     SPI=STAT*COUL*FORM
      RETURN
      END
*
*------------------------------------------------------------------------
*  This subroutine calculates the Fermi function value for arguments
*  values A,Z and W=E2+1
*
      DOUBLE PRECISION FUNCTION FERMI (ISIGNE,P,PI,R,GAMMA,DELTA)
      DOUBLE PRECISION MODGAC,MODGAR,GAMMA,DELTA,P,R,PI,PSIG
*
*  MODGAC - square of the absolute value of the complex gamma function
*  MODGAR - square of the real value of the complex gamma function 
*
      PSIG = DBLE(FLOAT(ISIGNE))
      FERMI =  2.D0*(1.D0+GAMMA) * (2.D0*P*R)**(2.D0*(GAMMA-1.D0))
     %       * DEXP(PSIG*PI*DELTA) * MODGAC(GAMMA,DELTA)
     %       / MODGAR(2.D0*GAMMA+1.D0)
      RETURN
      END
*
*------------------------------------------------------------------------
*  This subroutine calculates square of the absolute value of the complex
*  gamma function
*
      DOUBLE PRECISION FUNCTION MODGAC(A,B)
      DOUBLE PRECISION A,B,X(2),Y(2),Z(2)
*
*  LOGACO - subroutine calculates logarithm of the complex gamma function
*
      X(1)=A
      X(2)=B
      CALL LOGACO(X,Y)
*
*  calculation of the exponential function of the complex number
*
      Z(1) = DEXP(Y(1))*DABS(DCOS(Y(2)))
      Z(2) = DEXP(Y(1))*DABS(DSIN(Y(2)))
      MODGAC=Z(1)**2+Z(2)**2
      RETURN
      END
*
*------------------------------------------------------------------------
*  This subroutine calculates square of the real value of the complex
*  gamma function
*
      DOUBLE PRECISION FUNCTION MODGAR(U)
      DOUBLE PRECISION U,GAMMAR
*
      MODGAR=GAMMAR(U)*GAMMAR(U)
      RETURN
      END
*
*----------------------------------------------------------------------
*  This subroutine calculates the real function gamma of Y=N+X for Y>=1
*  Gamma of (1+X) is calculated by using coefficients given by
*  ABRAMOWITZ and STEGUN formula 6.1.36 page 257.
*  Gamma of (N+X) is obtained from formula 1.16.
*
      DOUBLE PRECISION FUNCTION GAMMAR(Y)
      DOUBLE PRECISION B(8),X,Y,D,F
      DATA B/-.577191652,+.988205891,-.897056937,+.918206857,
     %       -.756704078,+.482199394,-.193527818,+.035868343/
*
      N = IDINT(Y)
      X = Y - DBLE(REAL(N))
      D = 1.D0
      DO 1 I=1,8
	 D = D + B(I)*X**I
1        CONTINUE
      F = 1.D0
      DO 2 I=1,N-1
	 F = F * (DBLE(REAL(I))+X)
2        CONTINUE
      GAMMAR=F*D
      RETURN
      END
*
*-------------------------------------------------------------------
*  This subroutine calculates logarithm of complex gamma function.
*  For numbers higher than 10 it uses the Stirling formula. For
*  numbers lower than 10 the real value is increased to become higher
*  than 10, the result is than brought to a value corresponding to 
*  initial one by a shift along the real axis by using a formula:
*  Log(Gamma(X))=Log(Gamma(X+N))-Log(X)-Log(X+1)-....-Log(X+N-1)
*
      SUBROUTINE LOGACO (X,Y)
      DOUBLE PRECISION X(2),X1(2),Y(2),Z(2),DECAL
*
*  If the real value < 10 a shift is necessary on the complex plane
*  DECAL - a shift to the region: (REEL(X) > 10)
*
      IF (X(1).GE.10.D0) GO TO 1
      A = X(1)
      DECAL = 10.D0-DBLE(AINT(A))
      X1(1) = X(1)+DECAL
      X1(2) = X(2)
*
*  A Stirling formula is now applied
*  and at the end the shift compensating terms are subtracted
*
      CALL LSTIRL (X1,Y)
      N = IDINT(DECAL)
      X1(1) = X(1)
      DO 2 I=1,N
*
*  calculation of the logarithm of the complex number
*  and the difference of two complex number
*  
	 Z(1) = DLOG(X1(1)**2+X1(2)**2)/2
	 Z(2) = DATAN(X1(2)/X1(1))
	 Y(1) = Y(1)-Z(1)
	 Y(2) = Y(2)-Z(2)
         X1(1) = X1(1)+1.D0
2        CONTINUE
      RETURN
*
1     CALL LSTIRL (X,Y)
      RETURN
      END
*
*---------------------------------------------------------------------
*  This subroutine calculates the Stirling formula of logarithms
*  of complex numbers
*  LOG(GAMMA(X))= (X-1/2).LOG(X)-X+(1/2).LOG(2.PI)+(1/12X)-(1/360X3)
*                 +(1/1260X5)-(1/1680X7)+(1188X9)-(691/360360X11)
*                 +(1/156X13)-(3617/122400X15)
*
      SUBROUTINE LSTIRL (X,SOM)
      DOUBLE PRECISION X(2),X1(2),X2(2),X3(2),XINV(2),XINV2(2),
     %   COEF(10),SOM(2),DD
*
*  calculation of term (X-1/2).LOG(X);
*  calculation of the difference of two complex number, the logarithm
*  of the complex number and the product of two complex number
*
	X1(1) = X(1)-0.5D0
	X1(2) = X(2)
	X2(1) = DLOG(X(1)**2+X(2)**2)/2
	X2(2) = DATAN(X(2)/X(1))
	X3(1) = X1(1)*X2(1)-X1(2)*X2(2)
	X3(2) = X1(1)*X2(2)+X1(2)*X2(1)	
*
*  summation initialization;
*  calculation of the sum of two complex number
*
	SOM(1) = X3(1)
	SOM(2) = X3(2)
*
*  summation of the second term
*  (calculation of the difference of two complex number)
*
	SOM(1) = SOM(1)-X(1)
	SOM(2) = SOM(2)-X(2)
*
*  summation of the third term : (1/2)LOG(2PI) = 0.91893853320467E00
*
	X1(1)=.91893853320467D0
	X1(2)=.0D0
	SOM(1) = SOM(1)+X1(1)
*
*  calculation of 1/X (division of two complex number)
*  and of 1/X square (the product of two complex number)
*
	DD = X(1)**2+X(2)**2
	XINV(1) = X(1)/DD
	XINV(2) = -X(2)/DD
	XINV2(1) = XINV(1)**2-XINV(2)**2
	XINV2(2) = XINV(1)*XINV(2)*2.D0
*
*  introduction of expansion coefficients
*
	COEF(1) = 1.D0/12.D0
	COEF(2) = -1.D0/360.D0
	COEF(3) = 1.D0/1260.D0
	COEF(4) = -1.D0/1680.D0
	COEF(5) = 1.D0/1188.D0
	COEF(6) = - 691.D0/360360.D0
	COEF(7) = 1.D0/156.D0
	COEF(8) = -3617.D0/122400.D0
*
*  calculating first term of expansion and summation;
*  (calculation of the product of the complex number and the scalar,
*   and then calculation of the sum of two complex number)   
*
	X1(1) = COEF(1)*XINV(1)
	X1(2) = COEF(1)*XINV(2)
	SOM(1) = SOM(1)+X1(1)
	SOM(2) = SOM(2)+X1(2)
*
*  calculating terms of expansion and summation
*
	DO 1 I=1,2
1          X1(I)=XINV(I)
	DO 1000 I=2,8
*
*  calculating odd powers of 1/X  (the product of two complex number),
*  multiplication by corresponding coefficients (the product of the 
*  complex number and the scalar), and summation of two complex number
*
	   X1(1) = X1(1)*XINV2(1)-X1(2)*XINV2(2)
	   X1(2) = X1(1)*XINV2(2)+X1(2)*XINV2(1)
	   X3(1) = COEF(I)*X1(1)
	   X3(2) = COEF(I)*X1(2)
	   SOM(1) = SOM(1)+X3(1)
	   SOM(2) = SOM(2)+X3(2)
1000       CONTINUE
      RETURN
      END
********************************************************************
*  SUBROUTINE  FJON
*  - For calculating of scintillation energies in all intervals
*    of the beta spectrum, taking into account the Birks formula
*    describing the ionization quenching effect with the kB parameter.
*    Calculations are performed for the chosen scintillator of a 
*    given dimensions.
*
*  Input:
*    NCAN - number of intervals in the beta spectrum (maximum 500)
*    EB(ncan) - table of beta particles energy (energies are
*               taken from the middle of each interval)
*    XKB - the ionization quenching parameter kB
*    R - radius of the scintillator cylindrical column
*    H - height of the scintillator cylindrical column
*    RO - density of the scintillator
*    ZA - ratio of the atomic to the mass number of the scintillator
*    EJ - mean exciting energy of the scintillator molecules
*
*  Output:
*    FE(NCAN) - table of scintillation energies (the total energy
*               of photons e.g. the beta energy EB multiplied by the
*               relative scintillation efficiency)
*
	SUBROUTINE FJON (ncan,eb,xkb,r,h,ro,za,ej,FE)
	DOUBLE PRECISION EB(NCAN),EN,FE(NCAN),PAS,QE(500),RH,RNG,
     1	                 S1,S2,SOM,WE(500),XKB
*
        RH = DBLE((R+H)/(R*H*2.))
*
*  Beta particle energies EB are taken from the middle of each beta
*  spectrum interval; the Birks function and the track of beta
*  particle are integrated in the limits [0,EB]; while a PAS - is
*  the beta spectrum interval width
*
	PAS = EB(NCAN)/(FLOAT(NCAN)-0.5)
	RNG = 0.D0
	SOM = 0.D0
	DO 300 N=1,NCAN
	   EN = EB(N)
*-------------------------------------------------------------------
*  Subroutine BIRKS
*  - for calculating integral in the Birks formula (S1) and
*    a track of beta particle (S2) in the limits [EB-PAS/2,EB+PAS/2]
*
	   CALL BIRKS (en,pas,xkb,ro,za,ej,S1,S2)
*
*  QE(n) function [the relative scintillation efficiency multiplied
*  by energy EB], as well as the range RNG of beta particle of EB(n)
*  energy, are calculated by summing the QE(n-1) value for the EB(n-1)
*  beta energy and integrated value, calculated in the two energy
*  interval [EB(N-1),EB(N)]
*
	   SOM = SOM+S1
	   QE(N) = SOM
	   RNG = RNG+S2
	   WE(N) = 1.D0-RH*RNG
*
*  The function FE is a product of QE and WE (the probability
*  that the beta particle of energy EB remains in the volume of scintillator)
*
*  (Practical limit for the beta particle energy:   EB>3.1 MeV
*   the range RNG>1.5 cm, so it may be assumed, that there is no interactions
*   in the scintillator volume)
*
	   IF (WE(N).LT.0.D0) WE(N)=0.0D0
	   FE(N) = QE(N)*WE(N)
300	   CONTINUE
	RETURN
	END
***************************************************************************
*  SUBROUTINE BIRKS
*  - For calculating the integral in the Birks formula (S1) for a track
*    of beta particle (S2) in the range [EN-PAS/2,EN+PAS/2]. Calculation is 
*    performed for the chosen scintillator of a given dimension.
*
*  Calculation of dE/dX by the relativistic Bethe-Bloch formulae.
*  Integration by using the 5-points Simpson method.
*  Assumptions: - for EN<0.1 keV, dE/dX is proportional to EN,
*               - the low limit in the Birks function integral is EJ
*                 (mean exciting energy of the scintillator molecules),
*               - range is 0 for the beta particle of energy EN=0 keV,
*
*  Input:
*    EN - beta particle energy
*    PAS - width of the beta spectrum interval
*    XKB - ionization quenching parameter kB
*    RO - density of scintillator
*    ZA - ratio of the atomic to the mass number of scintillator
*    EJ - mean exciting energy of the scintillator molecules
*
*  Output:
*    S1 - an integral in the Birks formula in the limits [EN-PAS,EN]
*    S2 - a track of beta particle in the limits [EN-PAS,EN] calculated
*         as an integral of reciprocal of dE/dX
*
	SUBROUTINE BIRKS (en,pas,xkb,ro,za,ej,S1,S2)
	DOUBLE PRECISION B,DEDX,DEDX1,E(5),E1,EI,EJM,EJX,EL,EN,
     1	                 HH,PAS,QE(5),S1,S2,XKB,Y,YD(5),Z,ZAX
	DATA EL /511.003D0/, E1 /0.1D0/
*
	ZAX = 0.153536D0*DBLE(ZA)*RO
	EJX = 1.165822D0/DBLE(EJ)
	EJM = 0.5D0/(EL*EJ*EJ)
*
	HH = PAS/4.D0
        E(1) = EN-HH*2.D0
        E(2) = EN-HH
        E(3) = EN
        E(4) = EN+HH
        E(5) = EN+HH*2.D0
*
	DO 100 I=1,5
	   EI = E(I)
*
*  the relative scintillation efficiency for beta energy EI
*  multiplied by this energy is QE(I)=0 when EI<0
*  so the lower limit in the Birks formula integral is 0
*
	   QE(I) = 0.D0
	   YD(I) = 0.D0
	   IF (EI.LE.0.D0) GO TO 100
*
	   Y = (EL+EI)**2
	   B = 1.D0-(EL*EL)/Y
*
*  Assumption: proportionality dE/dX to EI for EI<E1 ;
*  DEDX1 - the value of dE/dX for EI=E1
*
	   IF (EI.LE.E1) THEN
	      Y = (EL+E1)**2
	      B = 1.D0-(EL*EL)/Y
	      Z = 2.D0*DSQRT(1.D0-B)+B
	      DEDX1 = (DLOG(E1*Y*B*EJM)+1.D0-B-DLOG(2.D0)
     1                *(Z-1.D0)+0.125D0*(2.D0-Z))*ZAX/B
              DEDX = DEDX1*EI/EI
	      GO TO 80
	   ENDIF
*
	   Z = 2.D0*DSQRT(1.D0-B)+B
	   DEDX = (DLOG(EI*Y*B*EJM)+1.D0-B-DLOG(2.D0)
     1            *(Z-1.D0)+0.125D0*(2.D0-Z))*ZAX/B
*
80	   YD(I) = 0.001D0/DEDX
	   QE(I) = 1.D0/(1.D0+XKB*DEDX)
100	   CONTINUE
*
*  sums S1 and S2 are integrals calculated by using the 5-points
*  Simpson method
*
	S1 = (QE(1)+4.D0*QE(2)+2.D0*QE(3)+4.D0*QE(4)+QE(5))*HH/3.D0
	S2 = (YD(1)+4.D0*YD(2)+2.D0*YD(3)+4.D0*YD(4)+YD(5))*HH/3.D0
*
	RETURN
	END
****************************************************************************
*  SUBROUTINE EFFIC2
*  - For calculating counting probabilities at all counting channels,
*    pulse amplitude spectrum and its integral (counting efficiency).
*    Spectrum integration is performed by using a rectangle method.
*
*  Assumptions: The Poisson distribution of photoelectrons is applied.
*
*  Input:
*    SPEB(NCAN) - table of the normalized beta spectrum
*    NCAN - number of intervals in the beta spectrum
*    FE(NCAN) - table of scintillation energies
*    ETA1,ETA2,ETA3 - figure of merit for the PM-tube A, B and C
*
*  Output:
*    CEAB - counting efficiency at the double coincidence channel AB
*    CEBC -    "         "      "   "    "           "       "    BC
*    CEAC -    "         "      "   "    "           "       "    AC
*    CET -     "         "      "   "  triple        "       "    T
*    CED -     "         "      "   "  sum of double "       "    D  
*    PHEL - expected number of photoelectrons in detector
* 
	SUBROUTINE EFFIC2 (eta1,eta2,eta3,ncan,fe,speb,CEAB,CEBC,CEAC,
     1	                   CET,CED,PHEL)
*
	DOUBLE PRECISION CEAB,CEBC,CEAC,CET,CED,FE(NCAN),ETA1,ETA2,ETA3,
     1     ETA0,PA,PB,PC,PAB,PAC,PBC,PT,AB,AC,BC,T,D,SPEB(NCAN)
*
	CEAB = 0.D0
	CEBC = 0.D0
	CEAC = 0.D0
	CET = 0.D0
	CED = 0.D0
	PHEL = 0.D0
*
*  ETA0 - the detector figure of merit
*
	ETA0 = ETA1+ETA2+ETA3
	DO 10 I=1,NCAN
	   PHEL = PHEL+ETA0*FE(I)*SPEB(I)
	   PA= DEXP(-FE(I)*ETA1/3.D0)
	   PB= DEXP(-FE(I)*ETA2/3.D0)
	   PC= DEXP(-FE(I)*ETA3/3.D0)
*
	   PAB = PA*PB
	   PAC = PA*PC
	   PBC = PB*PC
	   PT = PA*PB*PC
*
*  counting probabilities at all counting channels
*
	   AB = 1.D0-(PA+PB-PAB)
	   BC = 1.D0-(PB+PC-PBC)
	   AC = 1.D0-(PA+PC-PAC)
	   T = 1.D0-(PA+PB+PC-PAB-PBC-PAC+PT)
	   D = 1.D0-(PAB+PBC+PAC-2.*PT)
*
*  counting efficiencies at all counting channels
*
	   CEAB = CEAB+SPEB(I)*AB
	   CEBC = CEBC+SPEB(I)*BC
	   CEAC = CEAC+SPEB(I)*AC
	   CET = CET+SPEB(I)*T
	   CED = CED+SPEB(I)*D
10 	   CONTINUE
*
	RETURN
	END
************************************************************************
*  SUBROUTINE FIT      (Version  FIT-3)
*  - For calculating counting efficiencies in a given counting point
*    at all counting channels (AB, BC, CA - double coincidence;
*    T - triple coincidence; D - sum of double coincidence).
*    Calculated theoretical T/AB, T/BC and T/AC ratios are fitting
*    to the experimental ones by using a downhill simplex method.
*    Differences between theoretical and experimental ratios should
*    be lower than DEL.
*
*  Input:
*    NCAN - number of intervals in the beta spectrum
*    FE(NCAN) - table of scintillation energies
*    SPEB(NCAN) - table of the normalized beta spectrum
*    TDCR1 - the experimental T/AB ratio at a counting point
*    TDCR2 - the experimental T/BC ratio at a counting point
*    TDCR3 - the experimental T/AC ratio at a counting point
*    DEL - acceptable difference between the theoretical 
*          and experimental ratio
*  Output:
*    CEAB -  counting efficiency at the AB coincidence channel
*    CEBC -     "        "       "  the BC        "      "
*    CECA -     "        "       "  the AC        "      "
*    CET  -     "        "       "  the T         "      "
*    CED  -     "        "       "  the D         "      "
*    PHEL - the expected number of photoelectrons in detector at
*           each counting point
*    ETA1M,ETA2M,ETA3M - figure of merit of the PM-tube A, B and C
*                        respectively
*
	SUBROUTINE FIT (ncan,fe,speb,tdcr1,tdcr2,tdcr3,del,CEAB,
     1	                CEBC,CEAC,CET,CED,PHEL,ETA1M,ETA2M,ETA3M)
	DOUBLE PRECISION DEL,FE(NCAN),SPEB(NCAN),P(4,3),TDCR1,
     1     TDCR2,TDCR3,CEAB,CEBC,CEAC,CET,CED,ETA1M,ETA2M,ETA3M
*
	P(1,1) = 0.1
	P(1,2) = 0.01
	P(1,3) = 0.01
	P(2,1) = 0.01
	P(2,2) = 0.1
	P(2,3) = 0.01
	P(3,1) = 0.01
	P(3,2) = 0.01
	P(3,3) = 0.1
	P(4,1) = 0.4
	P(4,2) = 0.4
	P(4,3) = 0.4
*
*-------------------------------------------------------------------
*  Subroutine AMOEBA
*  - for fitting theoretical T/AB, T/BC and T/AC ratios to the 
*    experimental ones by using a downhill simplex method.
*    A sum:    (R1-TDCR1)^2+(R2-TDCR2)^2+(R3-TDCR3)^2
*    is minimalized where R1,R2,R3 are theoretical and 
*    TDCRB1,TDCRB2,TDCRB3 experimental values of T/AB, T/BC and T/AC
*    ratios respectively.
*
 	CALL AMOEBA (p,del,ncan,fe,speb,tdcr1,tdcr2,tdcr3,ETA1M,
     1	             ETA2M,ETA3M)
*
*--------------------------------------------------------------------
*  Subroutine EFFIC2
*  - for calculating counting probabilities and counting efficiencies
*    at all counting channels
*
	CALL EFFIC2 (eta1m,eta2m,eta3m,ncan,fe,speb,CEAB,CEBC,CEAC,CET,
     1	             CED,PHEL)
*
	RETURN
	END
************************************************************************
*
* SUBROUTINE AMOEBA
* - For multidimensional minimalization of the function FUNK(X), where X
*   is an NDIM-dimensional vector, by the downhill simplex metod
*   (by Nelder and Mead) [in: Numerical Recipes, W.H.Press, B.P.Flannery,
*   S.A. Teukolsky, W.T. Vetterling]. 
*
*  Input:
*   P(mp,np) - matrix which contains mp=np+1 of np-dimensional vectors 
*              which determined vertices of the starting simplex
*              (starting points for minimalization)
*   NCAN - number of intervals in the beta spectrum
*   FE(NCAN) - table of scintillation energies
*   SPEB(NCAN) - table of the normalized beta spectrum
*   TDCR1 - the experimental T/AB ratio at a counting point
*   TDCR2 - the experimental T/BC ratio at a counting point
*   TDCR3 - the experimental T/AC ratio at a counting point
*   DEL - acceptable difference between the theoretical and
*         experimental ratio
*  Output:
*   ETA1M,ETA2M,ETA3M - determined by minimalization method the figure
*                       of merit of A,B,C PM-tube respectively 
*
	SUBROUTINE AMOEBA (p,del,ncan,fe,speb,tdcr1,tdcr2,tdcr3,
     1	                   ETA1M,ETA2M,ETA3M)
*
	PARAMETER (MP=4,NP=3,NDIM=3,NMAX=3,ALPHA=1.0,BETA=0.5,
     1	   GAMMA=2.0,ITMAX=500)
	DOUBLE PRECISION P(MP,NP),Y(MP),PR(NMAX),PRR(NMAX),
     1     PBAR(NMAX),FE(NCAN),SPEB(NCAN),DEL,TDCR1,TDCR2,TDCR3,
     1	   CEAB,CEBC,CEAC,CET,CED,ETA1M,ETA2M,ETA3M,ETA1,ETA2,ETA3
*
*  preinitialization of the Y vector which will be minimalized
*
	DO 700 I=1,MP
           ETA1 = P(I,1)
           ETA2 = P(I,2)
           ETA3 = P(I,3)
*
           CALL EFFIC2 (eta1,eta2,eta3,ncan,fe,speb,CEAB,CEBC,
     1                  CEAC,CET,CED,PHEL)
*
           Y(I) = (CET/CEAB-TDCR1)**2+(CET/CEBC-TDCR2)**2+
     1            (CET/CEAC-TDCR3)**2
700 	   CONTINUE
	MPTS = NDIM+1
	ITER = 0
*
1	ILO = 1
	IF (Y(1).GT.Y(2)) THEN
	   IHI = 1
	   INHI = 2
	ELSE
	   IHI = 2
	   INHI = 1
	ENDIF
	DO 11 I=1,MPTS
	   IF (Y(I).LT.Y(ILO)) ILO=I
	   IF (Y(I).GT.Y(IHI)) THEN
	      INHI=IHI
	      IHI=I
	   ELSE IF(Y(I).GT.Y(INHI))THEN
	      IF(I.NE.IHI) INHI=I
	   ENDIF
11	   CONTINUE
*
	RTOL = 0.
	DO 31 K=1,MP
	   RTOL = RTOL+(Y(K)*Y(K))
31	   CONTINUE
	RTOL = DSQRT(RTOL)
*
*  ITER gives the number of iterations taken
*
	IF (RTOL.LT.DEL) GO TO 1000
	IF (ITER.EQ.ITMAX) GO TO 1000
	ITER = ITER+1
	DO 12 J=1,NDIM
	   PBAR(J) = 0.
12	   CONTINUE
	DO 14 I=1,MPTS
	   IF (I.NE.IHI) THEN
	      DO 13 J=1,NDIM
	         PBAR(J) = PBAR(J)+P(I,J)
13	         CONTINUE
	   ENDIF
14	   CONTINUE
*
	DO 15 J=1,NDIM
	   PBAR(J) = PBAR(J)/NDIM
	   PR(J) = (1.+ALPHA)*PBAR(J)-ALPHA*P(IHI,J)
15	   CONTINUE
*
        ETA1 = PR(1)
        ETA2 = PR(2)
        ETA3 = PR(3)
*
        CALL EFFIC2 (eta1,eta2,eta3,ncan,fe,speb,CEAB,CEBC,
     1               CEAC,CET,CED,PHEL)
*
        YPR = (CET/CEAB-TDCR1)**2+(CET/CEBC-TDCR2)**2+
     1        (CET/CEAC-TDCR3)**2
	IF (YPR.LE.Y(ILO)) THEN
	   DO 16 J=1,NDIM
	      PRR(J) = GAMMA*PR(J)+(1.-GAMMA)*PBAR(J)
16	      CONTINUE
*
           ETA1 = PRR(1)
           ETA2 = PRR(2)
           ETA3 = PRR(3)
*
           CALL EFFIC2 (eta1,eta2,eta3,ncan,fe,speb,CEAB,CEBC,
     1                  CEAC,CET,CED,PHEL)
*
           YPRR = (CET/CEAB-TDCR1)**2+(CET/CEBC-TDCR2)**2+
     1            (CET/CEAC-TDCR3)**2
	   IF (YPRR.LT.Y(ILO)) THEN
	      DO 17 J=1,NDIM
	         P(IHI,J) = PRR(J)
17	         CONTINUE
	      Y(IHI) = YPRR
	   ELSE
	      DO 18 J=1,NDIM
	         P(IHI,J) = PR(J)
18	         CONTINUE
	      Y(IHI)=YPR
	   ENDIF
	ELSE IF (YPR.GE.Y(INHI)) THEN
	   IF (YPR.LT.Y(IHI)) THEN
	      DO 19 J=1,NDIM
	         P(IHI,J) = PR(J)
19	         CONTINUE
	      Y(IHI)=YPR
	   ENDIF
	   DO 21 J=1,NDIM
	      PRR(J) = BETA*P(IHI,J)+(1.-BETA)*PBAR(J)
21	      CONTINUE
*
           ETA1 = PRR(1)
           ETA2 = PRR(2)
           ETA3 = PRR(3)
*
           CALL EFFIC2 (eta1,eta2,eta3,ncan,fe,speb,CEAB,CEBC,
     1                  CEAC,CET,CED,PHEL)
*
           YPRR = (CET/CEAB-TDCR1)**2+(CET/CEBC-TDCR2)**2+
     1            (CET/CEAC-TDCR3)**2
	   IF (YPRR.LT.Y(IHI)) THEN
	      DO 22 J=1,NDIM
	         P(IHI,J) = PRR(J)
22	         CONTINUE
	      Y(IHI) = YPRR
	   ELSE
	      DO 24 I=1,MPTS
	         IF (I.NE.ILO) THEN
	            DO 23 J=1,NDIM
	               PR(J) = 0.5*(P(I,J)+P(ILO,J))
	               P(I,J)=PR(J)
23	               CONTINUE
                    ETA1 = PR(1)
                    ETA2 = PR(2)
                    ETA3 = PR(3)
*
                    CALL EFFIC2 (eta1,eta2,eta3,ncan,fe,speb,CEAB,CEBC,
     1                           CEAC,CET,CED,PHEL)
*
                    Y(I) = (CET/CEAB-TDCR1)**2+(CET/CEBC-TDCR2)**2+
     1                     (CET/CEAC-TDCR3)**2
	         ENDIF
24	         CONTINUE
	   ENDIF
	ELSE
	   DO 25 J=1,NDIM
	      P(IHI,J) = PR(J)
25	      CONTINUE
	   Y(IHI)=YPR
	ENDIF
	GO TO 1
*
1000	ETA1M = (P(1,1)+P(2,1)+P(3,1)+P(4,1))/4. 	
	ETA2M = (P(1,2)+P(2,2)+P(3,2)+P(4,2))/4. 	
	ETA3M = (P(1,3)+P(2,3)+P(3,3)+P(4,3))/4. 	
*
	IF (ITER.EQ.ITMAX) THEN
	   WRITE(*,'('' ITER= '',I3,'' *** AMOEBA exceeds maximum '',
     1	   ''iterations !  (ETA1M='',F7.4,'')'')') ITER,ETA1M
	ELSE
	   WRITE (*,'('' ITER ='',I3)') ITER
	ENDIF
*
	RETURN
	END
***********************************************************************
*  SUBROUTINE SOURCE   (Version  SOURCE-3)
*  - For calculating activity of the source as a mean of all counting
*    points activities. For this purpose a slope of a regression line
*    of the set of counting points is calculated.
*
*  Input:
*    NP - number of counting points
*    A(np) - table of activity at counting points
*    TDCR(np) - table of experimental parameters TDCR at counting points
*
*  Output:
*    ACT - source activity 
*    SIGMA - standard deviation of the source activity ACT
*    AX,BX - the parameters of the regression line of the set
*            of counting points (%)
*    SIGAX - standard deviation of AX parameter
*
	SUBROUTINE SOURCE (np,a,tdcr,ACT,SIGMA,AX,BX,SIGAX)
	DOUBLE PRECISION A(NP),ACT,ACT2,AX,BX,SIGAX,SIGMA,SUMA,SUMA2,
     1	   SUMAT,SUMTD,SUMT2,TD,TDCR(NP),TT
*
*  the source activity ACT is calculated as a mean of activities
*  at all counting points
*
	SUMTD = 0.D0
	SUMA = 0.D0
	SUMA2 = 0.D0
	SUMAT = 0.D0
	SUMT2 = 0.D0
*
	DO 450 L=1,NP
	   SUMTD = SUMTD+TDCR(L)
	   SUMA = SUMA+A(L)
	   SUMA2 = SUMA2+A(L)**2
450	   CONTINUE
*
	TD = SUMTD/NP
	ACT = SUMA/NP
	DO 455 L=1,NP
	   TT = TDCR(L)-TD
	   SUMAT = SUMAT+TT*A(L)
	   SUMT2 = SUMT2+TT**2      
455	   CONTINUE
*
*  SIGMA - standard deviation of the source activity,
*
	ACT2 = ACT**2
	SIGMA = DSQRT((SUMA2-NP*ACT2)/(NP*(NP-1)))
*
*  calculation of the regression line ( A = AX*TDCR + BX )
*  of the set of counting points
*
	AX = SUMAT/SUMT2
	BX = ACT-AX*TD
*
*  calculation of SIGAX - the standard deviation of AX parameter
*
	SIGAX = DSQRT((SUMA2-AX*SUMAT-ACT*SUMA)/((NP-2)*SUMT2))
*
	RETURN 
	END
********************************************************************
*  Subprogram DESSIN     ( Version  DESSIN-5 )
*  - for printing tables and diagrams of a set of counting points 
*    as a function of the TDCR parameter
*
*  Input:
*    NOUT - number of the output device
*    IPRINT - printing option:
*     =1  printing tables and diagrams for all kB values
*     =2  printing diagrams and not tables for all kB values
*     =3  printing tables and diagrams only for interpolated kB values
*    NOPRINT - order of printing (=1 printing; =0 no printing)
*    IS - ordinal number of source
*    NP - number of counting points
*    A(np) - table of activity in counting points
*    ERR(np) - table of uncertainty of counting points
*    TDCR(np) - table of experimental parameter TDCR in counting points
*    ETA1(np) - figure of merit of PM-tube A at each counting point
*    ETA2(np) -    "   "    "   "  PM-tube B     "      "       "
*    ETA3(np) -    "   "    "   "  PM-tube C     "      "       "
*    SCOUNT(i,np) - table of counting point activity for all (i)
*                   counting channel and for all counting point
*    DIFF - test of mutual relation of all counting channel
*    EFFAB(np) - table of AB counting efficiency for all counting point
*    EFFBC(np) -   "   "  BC     "        "       "   "     "       "
*    EFFAC(np) -   "   "  AC     "        "       "   "     "       "
*    EFFT(np) -    "   "  T      "        "       "   "     "       "
*    EFFD(np) -    "   "  D      "        "       "   "     "       "
*    PHEL(np) - table of expected number of photoelectrons for all
*               counting points
*    E0A(np), E0B(np), E0C(np) - tables of overall optical efficiency of
*     the photomultiplier A, B and C respectively for all counting points
*    XKB - applied parameter kB value
*    ACT - the source activity
*    SIGMA - source activity standard deviation
*
	SUBROUTINE DESSIN (nout,iprint,noprint,is,np,a,err,tdcr,eta1,
     1                     eta2,eta3,scount,diff,effab,effbc,effac,
     2                     efft,effd,phel,xkb,act,sigma)
*
	DOUBLE PRECISION A(NP),ACT,DIFF(NP),EFFAB(NP),EFFBC(NP),
     1	   EFFAC(NP),EFFD(NP),EFFT(NP),ERR(NP),ETA0(30),SIGMA,TDCR(NP),
     2     XKB,DIFFt,ETA1(NP),ETA2(NP),ETA3(NP)
	REAL MAXY,MAXX,MINY,MINX,MINXA(5),PHEL(NP),PKT(30),RYS(62),
     2	   SCOUNT(5,NP)
	DATA PKT /'1','2','3','4','5','6','7','8','9','A','B','C',
     1            'D','E','F','G','H','I','J','K','L','M','N','O',
     2	          'P','R','S','T','U','V'/
*
	IF ((IPRINT.NE.3).OR.NOPRINT.EQ.1)
     1	   WRITE (NOUT,'(/'' *  kB='',F8.5,'' cm/MeV'')') XKB
*
	IF ((IPRINT.NE.2).AND.NOPRINT.EQ.1) THEN
           WRITE (NOUT,'(12X,''A    SIGMA   ETA0         T   effT'',
     1        ''         D   effD   TDCR  TDCRt'')')
	   DO 550 IP=1,NP
	      ETA0(IP) = ETA1(IP)+ETA2(IP)+ETA3(IP)
              WRITE (NOUT,'(1X,A1,F11.5,F9.5,F7.4,2(F10.3,F7.4),2F7.5)')
     1	         PKT(IP),A(IP),ERR(IP),ETA0(IP),SCOUNT(4,IP),EFFT(IP),
     2	         SCOUNT(5,IP),EFFD(IP),TDCR(IP),EFFT(IP)/EFFD(IP)
550	      CONTINUE
           WRITE (NOUT,'(/6X,''PHEL    DIFF   DIFFt        AB'',
     1        ''        BC        AC   ETA1   ETA2   ETA3'')')
	   DO 570 IP=1,NP
	      DIFFt = (EFFAB(IP)+EFFBC(IP)+EFFAC(IP))/(2.*EFFT(IP)+
     1	         EFFD(IP))-1.
              WRITE (NOUT,'(1X,A1,F8.3,2F8.6,3F10.3,3F7.4)') PKT(IP),
     1           PHEL(IP),DIFF(IP),DIFFt,SCOUNT(1,IP),
     2           SCOUNT(2,IP),SCOUNT(3,IP),ETA1(IP),ETA2(IP),ETA3(IP)
570	      CONTINUE
           WRITE (NOUT,'(/4X,''EFFAB  EFFBC  EFFAC'',6X,''TAB   TABt'',
     1        ''      TBC   TBCt      TAC   TACt'')')
	   DO 580 IP=1,NP
	      TAB = SCOUNT(4,IP)/SCOUNT(1,IP)  
	      TBC = SCOUNT(4,IP)/SCOUNT(2,IP)  
	      TAC = SCOUNT(4,IP)/SCOUNT(3,IP)
	      TABt = EFFT(IP)/EFFAB(IP)
	      TBCt = EFFT(IP)/EFFBC(IP)
	      TACt = EFFT(IP)/EFFAC(IP)
              WRITE (NOUT,'(1X,A1,3F7.4,3(2X,2F7.5))') PKT(IP),
     1          EFFAB(IP),EFFBC(IP),EFFAC(IP),TAB,TABt,TBC,TBCt,TAC,TACt
580	      CONTINUE
	ENDIF
*
	MAXY = ACT+SIGMA
	MINY = ACT-SIGMA
	YMOY = 0.
	XMOY = 0.
	MINX = 1.
	MAXX = 1.
*
*  calculation of a diagram dimension in 20 lines and 60 columns
*  (from MINY to MAXY, from MINX to MAXX)
*  and a distance between succeeding lines and columns (DELY,DELX);
* 
*  YMOY - mean value of activity of the counting points
*  XMOY - mean value of TDCR parameters of the counting points
*
        IF (NOPRINT.EQ.1) WRITE (NOUT,'(/1X,''A [kBq/g]'',26X,
     1     ''ACT ='',F11.5,'' +-'',F8.5,'' kBq/g'')') ACT,SIGMA
	   WRITE (*,'(/1X,''A [kBq/g]'',20X,''SOURCE No. ='',I2,10X,
     1	      ''  kB= '',F7.5'' cm/MeV''/)') IS,XKB
*
	DO 600 I=1,NP
	   Y = A(I)
	   ERY = ERR(I)
	   X = TDCR(I)
	   YMOY = YMOY+Y
	   XMOY = XMOY+X
	   IF ((Y+ERY).GT.MAXY) MAXY=Y+ERY
	   IF ((Y-ERY).LT.MINY) MINY=Y-ERY
	   IF (X.LT.MINX) MINX=X
600	   CONTINUE
*
	DELY = (MAXY-MINY)/20.
	DELX = (MAXX-MINX)/60.
	YMOY = YMOY/NP
	XMOY = XMOY/NP
*
*  a loop of lines succeeding (begins in the highest line);
*  AL, AH - a limit values in a given line
*
	AL = MAXY
	DO 605 L=1,21
	   DO 604 M=1,62
604	      RYS(M) = ' '
	   AH = AL
	   AL = AL-DELY
*
*  a loop of counting points succeeding;
*  symbol of the counting point PKT(i) is noted in the table RYS,
*  symbol "*" indicate the source activity ACT
*
	   DO 603 I=1,NP
	      X = TDCR(I)
	      Y = A(I)
	      ERY = ERR(I)
	      M = 61-INT((MAXX-X)/DELX)
	      IF ((Y+ERY).GE.AL.AND.(Y-ERY).LE.AH
     1           .AND.RYS(M).EQ.' ') RYS(M) = '!'
	      IF ((Y.GE.AL).AND.(Y.LE.AH)) RYS(M) = PKT(I)
603	      CONTINUE
*
	   IF ((ACT+SIGMA).GE.AL.AND.(ACT-SIGMA).LE.AH) RYS(62)='!'
	   IF (ACT.GE.AL.AND.ACT.LT.AH) RYS(62)='*'
*
*  printing of the coordinates of axis:
*  AL value is noted in each fifth line of the diagram;
*  five value of TDCR are noted in the diagram;
*
	   IF ((((L-1)/5)*5+1).NE.L) THEN
              IF (NOPRINT.EQ.1) WRITE (NOUT,'(10X,''!'',62A1)')
     1	         (RYS(M),M=1,62)
	      WRITE (*,'(8X,''!'',62A1)') (RYS(M),M=1,62)
	   ELSE
              IF (NOPRINT.EQ.1) WRITE (NOUT,'(1X,F9.4,''-'',62A1)')
     1	         AL,(RYS(M),M=1,62)
	      WRITE (*,'(1X,F7.2,''-'',62A1)') AL,(RYS(M),M=1,62)
	   ENDIF
605	   CONTINUE
*
	ODL = 15.*DELX
	DO 637 I=1,5
637	   MINXA(I) = MINX+ODL*(I-1)
        IF (NOPRINT.EQ.1) WRITE (NOUT,'(11X,''!'',4(14(1H-),1H!)/
     1     6X,4(F7.3,8X),F7.1/69X,''TDCR'')') (MINXA(I),I=1,5)
	IF (NOPRINT.EQ.1) WRITE (NOUT,'('' Distance between '',
     1	   ''succeeding lines ='',F7.4,'' ,  columns ='',F6.4)')
     2	   DELY,DELX
	WRITE (*,'(9X,''!'',4(14(1H-),1H!)/5X,4(F7.3,8X),
     1	   F7.3,1X,''TDCR'')') (MINXA(I),I=1,5)
*
	RETURN
	END
*********************************************************************
*  Subprogram INTRP
*  - For interpolation of function values between given points
*    by using the Lagrange polynomial of N-1 degree
*
*  Input:
*    NOUT - ordinal number of a printing device
*    N - number of points
*    X(n) - table of independent variables
*    F(n) - table of function values
*    XIN - value of X variable for interpolation
*
*  Output:
*    FIN - value of F function found by interpolation 
*
        SUBROUTINE INTRP (nout,n,x,f,xin,FIN)
        DOUBLE PRECISION B,F(N),FIN,H(10),X(N),XIN,Z(10)
*
        M = 0
        DO 20 K=1,N-1
           DO 25 L=K+1,N
              IF (X(K).EQ.X(L)) THEN
                 WRITE (NOUT,'('' ***  WARNING !!!   point (X,F)=('',
     1           2F9.5,'' )''/'' ***  have been omitted in an '',
     2           ''interpolation procedure'')') X(K),F(K)
                 GO TO 20
              ENDIF
25            CONTINUE
           M = M+1
           Z(M) = X(K)
           H(M) = F(K)
20         CONTINUE
        M = M+1
        Z(M) = X(K)
        H(M) = F(K)
*
	FIN = 0.D0
        DO 40 I=1,M
	   B = 1.D0
           DO 30 J=1,M
	      IF (J.EQ.I) GO TO 30
              B = B*(XIN-Z(J))/(Z(I)-Z(J))
30            CONTINUE            
40         FIN = FIN+B*H(I)
	RETURN
	END
****************************************************************
*  SUBROUTINE SETSOUR
*  - for calculating the mean activity of the solution 
*    (e.g. a set of sources)
* 
*  Input:
*    NS - number of sources in a set
*    SACT(ns) - table of source activities
*    SSIGMA(ns) - table of source standard deviations
*  Output:
*    N0SOL1 - mean activity of the solution
*    ER1 - mean activity standard deviation 
*
        SUBROUTINE SETSOUR (ns,sact,ssigma,N0SOL1,ER1)
*
        DOUBLE PRECISION ER1,N0SOL1,SACT(NS),SSIGMA(NS),SUM0,SUM1
*
        N0SOL1 = SACT(1)
        ER1 = SSIGMA(1)
	IF (NS.EQ.1) GO TO 800
*
	SUM0 = 0.D0
	SUM1 = 0.D0
*
*  calculation of the mean activity N0SOL1 and its uncertainty ER1
*
	DO 500 IS=1,NS
500	   SUM0 = SUM0+SACT(IS)
	N0SOL1 = SUM0/NS
	DO 550 IS=1,NS
550	   SUM1 = SUM1+(SACT(IS)-N0SOL1)**2
	ER1 = DSQRT(SUM1/(NS*(NS-1)))
*
800	RETURN
	END
****************************************************************************
*  SUBROUTINE RESULT      (version  RESULT-5)
*  - For printing and analysing results of calculation
*
*  Parameters and tables:
*    MASS(ns) - table of mass of sources
*    SKB(ns) - table of interpolated of kB parameter values
*              for all sources
*    SIGMAK(ns) - table of standard deviation of the SKB values
*    NOUT - ordinal number of printing device
*    NS - number of sources
*    KB(nkb) - table of ionisation quenching parameter kB values
*    NKB2 - number of different parameters kB (only NKB2-3 parameters kB
*           values are chosen for interpolation)
*    ACT(nkb,ns) - table of source activity values
*    SIGMA(nkb,ns) - table of standard deviation of the source activity 
*    SSIGMA(ns) - table of expanded "      "      "  "    "        "
*    AQ(nkb,ns) - table of parameters of the regression line
*            REG=TDEXP*AQ+BQ for all kB parameters values and all sources
*    SIGAX(nkb,ns) - table of AQ parameters standard deviation values
*    N0SOL1 - mean solution activity
*    ER1 - mean solution activity uncertainty
*    TDCRM(ns) - table of maximal value of the TDCR parameter in each source
*
        SUBROUTINE RESULT (nout,ns,nkb2,mass,skb,aq,sigax,kb,sigmak,act,
     1                     sigma,ssigma,n0sol1,er1,tdcrm)
        INTEGER NRL(12),NRM(12),NZ(12)
        REAL MASS(NS)
        DOUBLE PRECISION ACT(NKB2,NS),AQ(NKB2,NS),DISTA,DISTAM,
     1     DISTKB,DISKBM,ER1,HKB,HSL,KB(NKB2),LKB,MKB,N0SOL1,
     2     SIGAX(NKB2,NS),SIGMA(NKB2,NS),SIGSLOP,SKB(NS),SLOP(12),SLOPE,
     3	   SIGMAK(NS),SSIGMA(NS),TDCRM(NS)
*
	   WRITE (NOUT,'(/1X,74(1H=)/'' * FITTING OF A THEORETICAL '',
     1	      ''COUNTING EFFICIENCY TO THE COUNTING POINTS''/
     2	      '' * BY CHANGING kB PARAMETER VALUE'')')
*
*  SLOPE - slope values of the regression line of a set of counting points
*          for each source
*
	NKB = NKB2-2
	DO 150 IS=1,NS
           WRITE (NOUT,'(/'' * Source no.'',I2,4X,''kB [cm/MeV]'',10X,
     1        ''ACT [kBq/g]'',13X,''SLOPE [%]''/)') IS
           DO 150 K=1,NKB
	      SLOPE = (AQ(K,IS)/ACT(K,IS))*100.
              SIGSLOP = (SIGAX(K,IS)/ACT(K,IS))*100.
              IF (K.EQ.NKB) THEN
                 KB(K) = SKB(IS)
                 SLOP(IS) = SLOPE
              ENDIF
              WRITE (NOUT,'('' *'',19X,F7.5,5X,F11.5,'' +-'',F8.5,
     1           3X,F6.2,'' +-'',F7.2)')
     2           KB(K),ACT(K,IS),SIGMA(K,IS),SLOPE,SIGSLOP
150           CONTINUE
*
	WRITE (NOUT,'(/1X,74(1H=)
     1	   /'' Source  Mass       Activity'',15X,''kB       '',
     2	   ''        Slope  TDCRm''/'' no.     [mg]       [kBq/g]'',
     3	   16X,''[cm/MeV]''/)')
	MKB = 0.D0
	DO 450 IS=1,NS
	   MKB = MKB+SKB(IS)
*
           WRITE (NOUT,'(1X,I2,F10.3,F11.4,'' +-'',F7.4,
     1       3X,F7.4,'' +-'',F8.4,2X,F6.2'' %'',F7.4)') IS,MASS(IS),
     2	      ACT(NKB,IS),SSIGMA(IS),SKB(IS),SIGMAK(IS),SLOP(IS),
     3	      TDCRM(IS)
450	   CONTINUE
*
	MKB = MKB/NS
	ERR1 = (ER1/N0SOL1)*100.
        WRITE (NOUT,'(/'' MEAN'',8X,F11.4,'' +-'',F7.4,4X,F7.5/
     1	   23X,'' (+-'',F5.2,'' %)'',)') N0SOL1,ER1,MKB,ERR1
	WRITE (NOUT,'(/1X,74(1H=)//10X,''MEAN SOLUTION ACTIVITY''
     1	   ,'' = '',F9.3,'' +-'',F6.3,'' kBq/g   ( +-'',F5.2,'' % )'')')
     2	   N0SOL1,ER1,ERR1
*
*  analysis of the results
*
        WRITE (NOUT,'(/1X,74(1H=)//10X,''CONCLUSIONS  which may be'',
     1     '' drawn from the results :''/)')
        HKB = 0.020D0
        LKB = 0.002D0
        HSL = 2.D0
        DISTAM = 3.D0
        DISKBM = 40.D0
        I1 = 1
        I2 = 1
        J1 = 1
        J2 = 1
        DO 500 IS=1,NS
           NRL(IS) = 0
500        NRM(IS) = 0
*
        DO 510 IS=1,NS
           IF (SKB(IS).LT.SKB(I1)) I1=IS
           IF (SKB(IS).GT.SKB(I2)) I2=IS
           IF (ACT(NKB,IS).LT.ACT(NKB,J1)) J1 = IS
           IF (ACT(NKB,IS).GT.ACT(NKB,J2)) J2 = IS
510        CONTINUE
*
        DISTKB = 100.D0*DABS(SKB(I1)-SKB(I2))/SKB(I2)
        DISTA = 100.D0*DABS(ACT(NKB,J1)-ACT(NKB,J2))/ACT(NKB,J2)
        WRITE (NOUT,'('' * Difference between a source activity '',
     1     ''No.'',I2,'' and No.'',I2,'' is '',F6.2,'' %'')')
     2     J1,J2,DISTA
        IF (DISTA.GT.DISTAM) WRITE(NOUT,'('' * SPREAD OF THE '',
     1     ''RESULTS SEEMS TO BE TOO HIGH'')')
        WRITE (NOUT,'(/'' * Difference between kB values for '',
     1     ''a source No.'',I2,'' and No.'',I2,'' is '',F6.2,'' %'')')
     2     I1,I2,DISTKB
        IF (DISTKB.GT.DISKBM) WRITE(NOUT,'('' * THE DIFFERENCE '',
     1     ''SEEMS TO BE TOO HIGH'')')
*
        J = 0
        DO 520 IS=1,NS
           IF (SKB(IS).GT.LKB) GO TO 520
           J = J+1
           NZ(J) = IS
520        CONTINUE
        IF (J.GT.0) WRITE (NOUT,'(/'' * kB VALUE SEEMS TO BE TOO LOW''/
     1     '' * for the source No.'',12(I2,'', ''))') (NZ(N),N=1,J)
*
        J = 0
        DO 530 IS=1,NS
           IF (SKB(IS).LT.HKB) GO TO 530
           J = J+1
           NZ(J) = IS
530        CONTINUE
        IF (J.GT.0) WRITE (NOUT,'(/'' * kB VALUE SEEMS TO BE TOO HIGH''
     1     /'' * for the source No.'',12(I2,'', ''))') (NZ(N),N=1,J)
*
        J = 0
        DO 540 IS=1,NS
           IF (DABS(SLOP(IS)).LT.HSL) GO TO 540
           J = J+1
           NZ(J) = IS
540        CONTINUE
        IF (J.GT.0) WRITE (NOUT,'(/'' * A REGRESSION LINE SEEMS TO '',
     1     ''BE TOO MUCH INCLINED''/'' * for the source No.'',
     2     12(I2,'', ''))') (NZ(N),N=1,J)
*
	RETURN
	END

